@@ -68,7 +68,7 @@
 #endif
 
 #ifndef LOGIN_NAME_MAX
-# define LOGIN_NAME_MAX 9
+# define LOGIN_NAME_MAX 32
 #endif
 
 #ifndef MAXLOGNAME
@@ -369,21 +369,6 @@ typedef uint16_t	in_port_t;
 
 /* Function replacement / compatibility hacks */
 
-#ifndef HAVE_GETOPT_OPTRESET
-# undef getopt
-# undef opterr
-# undef optind
-# undef optopt
-# undef optreset
-# undef optarg
-# define getopt(ac, av, o)  BSDgetopt(ac, av, o)
-# define opterr             BSDopterr
-# define optind             BSDoptind
-# define optopt             BSDoptopt
-# define optreset           BSDoptreset
-# define optarg             BSDoptarg
-#endif
-
 #if defined(BROKEN_GETADDRINFO) && defined(HAVE_GETADDRINFO)
 # undef HAVE_GETADDRINFO
 #endif
@@ -518,4 +503,8 @@ typedef uint16_t	in_port_t;
 #define LOG_PERROR 0
 #endif
 
+#ifndef MAXDNAME
+#define MAXDNAME 1025
+#endif
+
 #endif /* _DEFINES_H */
