@@ -5,7 +5,6 @@
  */
 
 #include "includes.h"
-#ifndef HAVE_EXPLICIT_BZERO
 
 #include <string.h>
 
@@ -14,4 +13,3 @@ explicit_bzero(void *buf, size_t len)
 {
 	memset(buf, 0, len);
 }
-#endif
