@@ -39,7 +39,7 @@ struct ibuf {
 
 struct msgbuf {
 	TAILQ_HEAD(, ibuf)	 bufs;
-	u_int32_t		 queued;
+	uint32_t		 queued;
 	int			 fd;
 };
 
@@ -65,11 +65,11 @@ struct imsgbuf {
 #define IMSGF_HASFD	1
 
 struct imsg_hdr {
-	u_int32_t	 type;
-	u_int16_t	 len;
-	u_int16_t	 flags;
-	u_int32_t	 peerid;
-	u_int32_t	 pid;
+	uint32_t	 type;
+	uint16_t	 len;
+	uint16_t	 flags;
+	uint32_t	 peerid;
+	uint32_t	 pid;
 };
 
 struct imsg {
@@ -100,13 +100,13 @@ int	 available_fds(unsigned int);
 void	 imsg_init(struct imsgbuf *, int);
 ssize_t	 imsg_read(struct imsgbuf *);
 ssize_t	 imsg_get(struct imsgbuf *, struct imsg *);
-int	 imsg_compose(struct imsgbuf *, u_int32_t, u_int32_t, pid_t,
-	    int, const void *, u_int16_t);
-int	 imsg_composev(struct imsgbuf *, u_int32_t, u_int32_t,  pid_t,
+int	 imsg_compose(struct imsgbuf *, uint32_t, uint32_t, pid_t,
+	    int, const void *, uint16_t);
+int	 imsg_composev(struct imsgbuf *, uint32_t, uint32_t,  pid_t,
 	    int, const struct iovec *, int);
-struct ibuf *imsg_create(struct imsgbuf *, u_int32_t, u_int32_t, pid_t,
-	    u_int16_t);
-int	 imsg_add(struct ibuf *, const void *, u_int16_t);
+struct ibuf *imsg_create(struct imsgbuf *, uint32_t, uint32_t, pid_t,
+	    uint16_t);
+int	 imsg_add(struct ibuf *, const void *, uint16_t);
 void	 imsg_close(struct imsgbuf *, struct ibuf *);
 void	 imsg_free(struct imsg *);
 int	 imsg_flush(struct imsgbuf *);
