@@ -96,7 +96,7 @@ const char *inet_ntop(int af, const void *src, char *dst, socklen_t size);
 char *strsep(char **stringp, const char *delim);
 #endif
 
-#ifndef HAVE_SETPROCTITLE
+#ifdef NEED_SETPROCTITLE
 void setproctitle(const char *fmt, ...);
 void compat_init_setproctitle(int argc, char *argv[]);
 #endif
@@ -334,6 +334,8 @@ const char *strerror(int);
 int usleep(unsigned int useconds);
 #endif
 
+int pipe2(int pipefd[2], int flags);
+
 char *get_progname(char *);
 
 
